<?php
/**
 * Felt Theme About Page logic.
 *
 * @package Felt
 */

function felt_lite_admin_setup() {
	/**
	 * Load the About page class
	 */
	// phpcs:ignore
	require_once 'ti-about-page/class-ti-about-page.php';

	/*
	* About page instance
	*/
	$config = array(
		// Menu name under Appearance.
		'menu_name'               => esc_html__( 'About Felt', 'felt' ),
		// Page title.
		'page_name'               => esc_html__( 'About Felt', 'felt' ),
		/* translators: Main welcome title */
		'welcome_title'         => sprintf( esc_html__( 'Welcome to %s! - Version ', 'felt' ), 'Felt' ),
		// Main welcome content
		'welcome_content'       => esc_html__( ' Felt is a free magazine‐style WordPress theme for publishers who want to showcase their fresh ideas. Thanks to the modular layout you can highlight what’s truly important for your tribe to enhance stronger bonds and become memorable. No matter if you are a blogger, journalist, designer or small entrepreneur, this theme will fit perfectly everytime.', 'felt' ),
		/**
		 * Tabs array.
		 *
		 * The key needs to be ONLY consisted from letters and underscores. If we want to define outside the class a function to render the tab,
		 * the will be the name of the function which will be used to render the tab content.
		 */
		'tabs'                    => array(
			'getting_started'  => esc_html__( 'Getting Started', 'felt' ),
			'recommended_actions' => esc_html__( 'Recommended Actions', 'felt' ),
			'recommended_plugins' => esc_html__( 'Useful Plugins','felt' ),
			'support'       => esc_html__( 'Support', 'felt' ),
			'changelog'        => esc_html__( 'Changelog', 'felt' ),
			'free_pro'         => esc_html__( 'Free VS PRO', 'felt' ),
		),
		// Support content tab.
		'support_content'      => array(
			'first' => array (
				'title' => esc_html__( 'Contact Support','felt' ),
				'icon' => 'dashicons dashicons-sos',
				'text' => wp_kses( __( 'We want to make sure you have the best experience using Felt. If you <strong>do not have a paid upgrade</strong>, please post your question in our community forums.', 'felt' ), wp_kses_allowed_html() ),
				'button_label' => esc_html__( 'Contact Support','felt' ),
				'button_link' => esc_url( 'https://wordpress.org/support/theme/felt' ),
				'is_button' => true,
				'is_new_tab' => true
			),
			'second' => array(
				'title' => esc_html__( 'Documentation','felt' ),
				'icon' => 'dashicons dashicons-book-alt',
				'text' => esc_html__( 'Need more details? Please check our full documentation for detailed information on how to use Felt.','felt' ),
				'button_label' => esc_html__( 'Read The Documentation','felt' ),
				'button_link' => 'https://pixelgrade.com/felt-lite-documentation/',
				'is_button' => false,
				'is_new_tab' => true
			)
		),
		// Getting started tab
		'getting_started' => array(
			'first' => array(
				'title' => esc_html__( 'Go to Customizer','felt' ),
				'text' => esc_html__( 'Using the WordPress Customizer you can easily customize every aspect of the theme.','felt' ),
				'button_label' => esc_html__( 'Go to Customizer','felt' ),
				'button_link' => esc_url( admin_url( 'customize.php' ) ),
				'is_button' => true,
				'recommended_actions' => false,
				'is_new_tab' => true
			),
			'second' => array (
				'title' => esc_html__( 'Recommended actions','felt' ),
				'text' => esc_html__( 'We have compiled a list of steps for you, to take make sure the experience you will have using one of our products is very easy to follow.','felt' ),
				'button_label' => esc_html__( 'Recommended actions','felt' ),
				'button_link' => esc_url( admin_url( 'themes.php?page=felt-welcome&tab=recommended_actions' ) ),
				'button_ok_label' => esc_html__( 'You are good to go!','felt' ),
				'is_button' => false,
				'recommended_actions' => true,
				'is_new_tab' => false
			),
			'third' => array(
				'title' => esc_html__( 'Read the documentation','felt' ),
				'text' => esc_html__( 'Need more details? Please check our full documentation for detailed information on how to use Felt.','felt' ),
				'button_label' => esc_html__( 'Documentation','felt' ),
				'button_link' => 'https://pixelgrade.com/felt-lite-documentation/',
				'is_button' => false,
				'recommended_actions' => false,
				'is_new_tab' => true
			)
		),
		// Free vs pro array.
		'free_pro'                => array(
			'free_theme_name'     => 'Felt',
			'pro_theme_name'      => 'Felt PRO',
			'pro_theme_link'      => 'https://pixelgrade.com/themes/felt-pro/?utm_source=felt-lite-clients&utm_medium=about-page&utm_campaign=felt-lite',
			/* translators: View link */
			'get_pro_theme_label' => sprintf( esc_html__( 'Get %s', 'felt' ), 'Felt Pro' ),
			'features'            => array(
				array(
					'title'       => esc_html__( 'Daring Design for Devoted Readers', 'felt' ),
					'description' => esc_html__( 'Felt\'s design helps you stand out from the crowd and create an experience that your readers will love and talk about. With a flexible home page you have the chance to easily showcase appealing content with ease.', 'felt' ),
					'is_in_lite'  => 'true',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Mobile-Ready For All Devices', 'felt' ),
					'description' => esc_html__( 'Felt makes room for your readers to enjoy your articles on the go, no matter the device they are using. We shaped everything to look amazing to your audience.', 'felt' ),
					'is_in_lite'  => 'true',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Widgetized Sidebars To Keep Attention', 'felt' ),
					'description' => esc_html__( 'The widget-based flexible system allows you to add your favorite widgets all over the Front Page and on the right side of your articles.', 'felt' ),
					'is_in_lite'  => 'true',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'New Widgets for Extra Flexibility', 'felt' ),
					'description' => esc_html__( 'Felt PRO gives you extra ways to showcase your articles in great style. Besides the Slideshow, Featured and Grid Posts widgets, the PRO version comes with much more: Carousel, List Posts, Categories Images, and many others.', 'felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Advanced Widgets Options', 'felt' ),
					'description' => esc_html__( 'Felt\'s PRO version comes with more widget options to display and filter posts. For instance, you can have far more control on setting the source of the posts (filtering by category, tags, etc.) or how they are displayed, everything to push the content to the right people and promote it by the blink of an eye.', 'felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Flexible Home Page Design', 'felt' ),
					'description' => esc_html__( 'Felt\'s PRO version has more Widget Areas available to enable you to place widgets on the Front Page Center, Footer or Below the Post at the end of your articles.', 'felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Reliable Support for All Kind of Ads', 'felt' ),
					'description' => esc_html__( 'Make money out of your website in various ways with the Promo Box widget. Use it to deliver quality ads to your audience, promote a special offer or anything else that helps you achieve your goals.', 'felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Sticky Menu and Reading Progress Bar', 'felt' ),
					'description' => esc_html__( 'Keep the menu at the top of your page while you scroll, making it more accessible on whatever page you are navigating. On article pages, we\'re pushing this concept even further and improve it with a Progress Bar, and at the end, it will switch to a link to the next article so you can keep momentum and maintain the attention of your readers.', 'felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Flexible Color Scheme with Style Manager', 'felt' ),
					'description' => esc_html__( 'Showcase your unique style in an easy and smart way by using an intuitive inter­face that allows you to change color palettes and fonts with a few clicks until they fully represent you and match your particular needs.','felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Advanced Typography Settings', 'felt' ),
					'description' => esc_html__( 'Adjust your fonts by taking advantage of a play­ground with 600+ fonts variety you can wisely choose from at any moment.','felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Premium Support and Assistance', 'felt' ),
					'description' => esc_html__( 'We offer ongoing customer support to help you get things done fast. This way, you save energy and time and focus on what brings you happiness. We know our products inside-out and we can lend a hand to help you save resources of all kinds.','felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'Friendly Self-Service', 'felt' ),
					'description' => esc_html__( 'We give you full access to an in-depth documentation to get the job done as quickly as possible. We don\'t stay in your way by offering you full access to our self-help tool directly from your Dashboard.', 'felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				),
				array(
					'title'       => esc_html__( 'No Credit Footer Link', 'felt' ),
					'description' => esc_html__( 'You can easily remove the "Theme: Felt by Pixelgrade" copyright from the footer area and make the theme yours from start to finish.', 'felt' ),
					'is_in_lite'  => 'false',
					'is_in_pro'   => 'true',
				)
			),
		),
		// Plugins array.
		'recommended_plugins'        => array(
			'already_activated_message' => esc_html__( 'Already activated', 'felt' ),
			'version_label' => esc_html__( 'Version: ', 'felt' ),
			'install_label' => esc_html__( 'Install and Activate', 'felt' ),
			'activate_label' => esc_html__( 'Activate', 'felt' ),
			'deactivate_label' => esc_html__( 'Deactivate', 'felt' ),
			'content'                   => array(
				array(
					'slug' => 'jetpack'
				),
				array(
					'slug' => 'wordpress-seo'
				)
			),
		),
		// Required actions array.
		'recommended_actions'        => array(
			'install_label' => esc_html__( 'Install and Activate', 'felt' ),
			'activate_label' => esc_html__( 'Activate', 'felt' ),
			'deactivate_label' => esc_html__( 'Deactivate', 'felt' ),
			'content'            => array(
				'jetpack' => array(
					'title'       => 'Jetpack',
					'description' => wp_kses( __( 'It is highly recommended that you install Jetpack so you can enable the <b>Portfolio</b> content type for adding and managing your projects. Plus, Jetpack provides a whole host of other useful things for you site.', 'felt' ), wp_kses_allowed_html() ),
					'check'       => defined( 'JETPACK__VERSION' ),
					'plugin_slug' => 'jetpack',
					'id' => 'jetpack'
				),
			),
		),
	);
	Felt_Lite_About_Page::init( $config );
}
add_action( 'after_setup_theme', 'felt_lite_admin_setup' );
